Django Suit documentation
=========================

**Django Suit - Modern theme for Django admin interface**.

About
-----

Django Suit is alternative theme/skin/extension for `Django <http://www.djangoproject.com>`_ admin app (administration interface).


Licence
-------

* Django Suit is licensed under `Creative Commons Attribution-NonCommercial 3.0 <http://creativecommons.org/licenses/by-nc/3.0/>`_ license.
* See licence and pricing: http://djangosuit.com/pricing/


Resources
---------

* Home page: http://djangosuit.com
* Licence and Pricing: http://djangosuit.com/pricing/
* Originally build by darklow https://github.com/darklow/django-suit
* Github: https://github.com/pulse-mind/django-suit
* Demo app v2 on Github: https://github.com/pulse-mind/django-suit/tree/v2/demo



Contents:

.. toctree::
   :maxdepth: 3

   install
   configure
   contribute


